@@ -1,4 +1,6 @@
-#    Copyright (C) 2015 Combox author(s). See AUTHORS.
+# -*- coding: utf-8 -*-
+#
+#    Copyright (C) 2015 Combox contributor(s). See CONTRIBUTORS.rst.
 #
 #    This file is part of Combox.
 #
@@ -378,7 +380,7 @@ class TestEvents(object):
 
 
     def test_NDM_ondeleted(self):
-        """Testing on_modified method in NodeDirMonitor"""
+        """Testing on_delete method in NodeDirMonitor"""
         nodes =  get_nodedirs(self.config)
         num_nodes =  len(get_nodedirs(self.config))
 
@@ -709,7 +711,7 @@ class TestEvents(object):
 
 
     def test_NDM_housekeep_create(self):
-        """Testing NodeDirMonitor's housekeep method's delete functionality."""
+        """Testing NodeDirMonitor's housekeep method's create functionality."""
 
         # test shard creation
         hmutant = "%s.mutant" % self.TEST_FILE
